==> number-float32-base-to-int32-0.0.2.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# toInt32

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Convert a [single-precision floating-point number][ieee754] to a signed 32-bit integer.

<section class="installation">

## Installation

```bash
npm install @stdlib/number-float32-base-to-int32
```

</section>

<section class="usage">

## Usage

```javascript
var float32ToInt32 = require( '@stdlib/number-float32-base-to-int32' );
```

#### float32ToInt32( x )

Converts a [single-precision floating-point number][ieee754] to a signed 32-bit integer.

```javascript
var float64ToFloat32 = require( '@stdlib/number-float64-base-to-float32' );

var y = float32ToInt32( float64ToFloat32( 4294967295.0 ) );
// returns 0

y = float32ToInt32( float64ToFloat32( 3.14 ) );
// returns 3

y = float32ToInt32( float64ToFloat32( -3.14 ) );
// returns -3

y = float32ToInt32( float64ToFloat32( NaN ) );
// returns 0

y = float32ToInt32( float64ToFloat32( Infinity ) );
// returns 0

y = float32ToInt32( float64ToFloat32( -Infinity ) );
// returns 0
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var randu = require( '@stdlib/random-base-randu' );
var round = require( '@stdlib/math-base-special-round' );
var MAX_INT = require( '@stdlib/constants-uint32-max' );
var float64ToFloat32 = require( '@stdlib/number-float64-base-to-float32' );
var float32ToInt32 = require( '@stdlib/number-float32-base-to-int32' );

var int32;
var f32;
var i;

for ( i = 0; i < 500; i++ ) {
    // Generate a random single-precision floating-point integer:
    f32 = float64ToFloat32( round( randu()*MAX_INT ) );

    // Convert the single-precision floating-point integer to a signed integer:
    int32 = float32ToInt32( f32 );

    console.log( 'float32: %d => int32: %d', f32, int32 );
}
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/number-float32-base-to-int32.svg
[npm-url]: https://npmjs.org/package/@stdlib/number-float32-base-to-int32

[test-image]: https://github.com/stdlib-js/number-float32-base-to-int32/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/number-float32-base-to-int32/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/number-float32-base-to-int32/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/number-float32-base-to-int32?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/number-float32-base-to-int32
[dependencies-url]: https://david-dm.org/stdlib-js/number-float32-base-to-int32/main

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/number-float32-base-to-int32/main/LICENSE

[ieee754]: https://en.wikipedia.org/wiki/IEEE_754-1985

</section>

<!-- /.links -->

==> number-float32-base-to-int32-0.0.6.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# toInt32

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Convert a [single-precision floating-point number][ieee754] to a signed 32-bit integer.

<section class="installation">

## Installation

```bash
npm install @stdlib/number-float32-base-to-int32
```

</section>

<section class="usage">

## Usage

```javascript
var float32ToInt32 = require( '@stdlib/number-float32-base-to-int32' );
```

#### float32ToInt32( x )

Converts a [single-precision floating-point number][ieee754] to a signed 32-bit integer.

```javascript
var float64ToFloat32 = require( '@stdlib/number-float64-base-to-float32' );

var y = float32ToInt32( float64ToFloat32( 4294967295.0 ) );
// returns 0

y = float32ToInt32( float64ToFloat32( 3.14 ) );
// returns 3

y = float32ToInt32( float64ToFloat32( -3.14 ) );
// returns -3

y = float32ToInt32( float64ToFloat32( NaN ) );
// returns 0

y = float32ToInt32( float64ToFloat32( Infinity ) );
// returns 0

y = float32ToInt32( float64ToFloat32( -Infinity ) );
// returns 0
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var randu = require( '@stdlib/random-base-randu' );
var round = require( '@stdlib/math-base-special-round' );
var MAX_INT = require( '@stdlib/constants-uint32-max' );
var float64ToFloat32 = require( '@stdlib/number-float64-base-to-float32' );
var float32ToInt32 = require( '@stdlib/number-float32-base-to-int32' );

var int32;
var f32;
var i;

for ( i = 0; i < 500; i++ ) {
    // Generate a random single-precision floating-point integer:
    f32 = float64ToFloat32( round( randu()*MAX_INT ) );

    // Convert the single-precision floating-point integer to a signed integer:
    int32 = float32ToInt32( f32 );

    console.log( 'float32: %d => int32: %d', f32, int32 );
}
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/number-float32-base-to-int32.svg
[npm-url]: https://npmjs.org/package/@stdlib/number-float32-base-to-int32

[test-image]: https://github.com/stdlib-js/number-float32-base-to-int32/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/number-float32-base-to-int32/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/number-float32-base-to-int32/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/number-float32-base-to-int32?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/number-float32-base-to-int32.svg
[dependencies-url]: https://david-dm.org/stdlib-js/number-float32-base-to-int32/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/number-float32-base-to-int32/main/LICENSE

[ieee754]: https://en.wikipedia.org/wiki/IEEE_754-1985

</section>

<!-- /.links -->
